@@ -68,6 +68,9 @@ KitaMainWindow::KitaMainWindow()
     // load completion
     loadCompletion();
 
+    // load ascii art
+    loadAsciiArt();
+
     // and a status bar
     statusBar() ->show();
 
@@ -135,6 +138,8 @@ KitaMainWindow::KitaMainWindow()
 
 KitaMainWindow::~KitaMainWindow()
 {
+    saveAsciiArt();
+
     saveCompletion();
 
     saveFavorites();
@@ -202,12 +207,19 @@ void KitaMainWindow::setupActions()
                           actionCollection(),
                           "window_show_subject_list" );
 
+    m_showAddressAction = new KToggleAction( i18n( "Show mail address field" ),
+                          0,
+                          this,
+                          SLOT( settingsShowMailAddress() ),
+                          actionCollection(),
+                          "settings_show_mail_address" );
+
     m_urlLine = new KLineEdit( "", 0 );
     new KWidgetAction( m_urlLine,
                        i18n( "URL Line" ),
                        0,
                        this,
-                       SLOT( slotUrlLine() )   /* dummy */,
+                       SLOT( slotUrlLine() )      /* dummy */,
                        actionCollection(), "url_line_action" );
 
     KStdAction::keyBindings( this, SLOT( optionsConfigureKeys() ), actionCollection() );
@@ -250,6 +262,7 @@ void KitaMainWindow::writeConfig( KConfig* config )
     config->setGroup( "Global" );
     config->writeEntry( "Font", KitaConfig::font() );
     config->writeEntry( "ThreadFont", KitaConfig::threadFont() );
+    config->writeEntry( "ShowMailAddress", KitaConfig::showMailAddress() );
 
     config->setGroup( "Color" );
     config->writeEntry( "Popup", KitaConfig::popupColor() );
@@ -272,6 +285,7 @@ void KitaMainWindow::readConfig( KConfig* config )
     config->setGroup( "Global" );
     KitaConfig::setFont( config->readFontEntry( "Font" ) );
     KitaConfig::setThreadFont( config->readFontEntry( "ThreadFont" ) );
+    KitaConfig::setShowMailAddresss( config->readBoolEntry( "ShowMailAddress" ) );
 
     setFont( KitaConfig::font() );
 
@@ -412,6 +426,12 @@ void KitaMainWindow::settingsMenuAboutToShow()
 {
     m_toolbarAction->setChecked( toolBar() ->isVisible() );
     m_statusbarAction->setChecked( statusBar() ->isVisible() );
+    m_showAddressAction->setChecked( KitaConfig::showMailAddress() );
+}
+
+void KitaMainWindow::settingsShowMailAddress()
+{
+    KitaConfig::setShowMailAddresss( m_showAddressAction->isChecked() );
 }
 
 void KitaMainWindow::optionsPreferences()
@@ -581,6 +601,42 @@ void KitaMainWindow::saveCompletion()
     config.sync();
 }
 
+void KitaMainWindow::loadAsciiArt()
+{
+    QString configPath = locateLocal( "appdata", "asciiart" );
+    QFile file( configPath );
+    if ( file.open( IO_ReadOnly ) ) {
+        QTextStream stream( &file );
+        stream.setEncoding( QTextStream::UnicodeUTF8 );
+
+        QStringList list;
+        QString str;
+
+        while ( ( str = stream.readLine() ) != QString::null ) {
+            if ( ! str.isEmpty() ) {
+                list << str;
+            }
+        }
+        KitaConfig::setAsciiArtList( list );
+    }
+}
+
+void KitaMainWindow::saveAsciiArt()
+{
+    QString configPath = locateLocal( "appdata", "asciiart" );
+    QFile file( configPath );
+    if ( file.open( IO_WriteOnly ) ) {
+        QTextStream stream( &file ) ;
+        stream.setEncoding( QTextStream::UnicodeUTF8 );
+
+        QStringList list = KitaConfig::asciiArtList();
+        QStringList::iterator it;
+        for ( it = list.begin(); it != list.end(); ++it ) {
+            stream << ( *it ) << endl;
+        }
+    }
+}
+
 void KitaMainWindow::slotThread( const Kita::Thread* thread )
 {
     setCaption( thread->name() );
