@@ -99,6 +99,7 @@ private slots:
     void windowMenuAboutToShow();
     void windowCloseTab();
     void settingsMenuAboutToShow();
+    void settingsShowMailAddress();
     void slotEditCopy();
     void slotEditFind();
     void slotViewReload();
@@ -126,6 +127,7 @@ private:
     KToggleAction *m_statusbarAction;
     KToggleAction *m_boardListAction;
     KToggleAction* m_subjectListAction;
+    KToggleAction* m_showAddressAction;
 
     KDockWidget* m_boardDock;
     KDockWidget* m_subjectDock;
@@ -139,6 +141,8 @@ private:
     void saveFavorites();
     void loadCompletion();
     void saveCompletion();
+    void loadAsciiArt();
+    void saveAsciiArt();
 };
 
 #endif // _KITA_H_
