@@ -18,6 +18,7 @@
 #include <qfile.h>
 #include <qclipboard.h>
 #include <qapplication.h>
+#include <qdatetime.h>
 
 // kdelibs/kio
 #include <kio/slaveconfig.h>
@@ -30,6 +31,7 @@
 #include <klocale.h>
 #include <kpopupmenu.h>
 #include <krun.h>
+#include <kdebug.h>
 
 #include "libkita/threadinfo.h"
 #include "libkita/thread.h"
@@ -74,9 +76,7 @@ void KitaSubjectView::loadThread( QListViewItem* item )
 {
     if ( ! item ) return ;
 
-    QString datName = item->text( Row_DatName );
-    KURL datURL = m_board->url();
-    datURL.addPath( "/dat/" + datName );
+    KURL datURL = item->text( Row_DatURL );
 
     Kita::Board::setName( Kita::datToBoard( datURL.url() ), m_board->name() );
     Kita::Thread::setName( datURL.url(), item->text( Row_Subject ) );
@@ -107,6 +107,9 @@ void KitaSubjectView::loadBoard( const Kita::Board* board )
     for ( unsigned i = 0; i < threadList.count(); i++ ) {
         Kita::Thread* thread = threadList.at( i );
 
+        QDateTime since;
+        since.setTime_t( KURL( thread->datURL() ).fileName().section( '.', 0, 0 ).toInt() );
+
         int readNum = cache->readNum( thread->datURL() );
         int resNum = thread->resNum();
 
@@ -117,7 +120,7 @@ void KitaSubjectView::loadBoard( const Kita::Board* board )
         item->setText( Row_Read, ( readNum > 0 ) ? QString( "%1" ).arg( readNum, 4 ) : QString( "" ) );
         item->setText( Row_Unread, ( readNum > 0 && resNum != readNum ) ? QString( "%1" ).arg( resNum - readNum, 4 ) : QString( "" ) );
         item->setText( Row_Board, thread->boardName() );
-        item->setText( Row_DatName, KURL( thread->datURL() ).fileName() );
+        item->setText( Row_Since, since.toString( "yy/MM/dd hh:mm" ) );
         item->setText( Row_DatURL, thread->datURL() );
 
         if ( readNum > 0 && resNum != readNum ) {
@@ -165,14 +168,7 @@ void KitaSubjectView::slotContextMenuRequested( QListViewItem* item, const QPoin
     popup.insertItem( i18n( "Open with new tab" ), 1 );
     popup.insertItem( i18n( "Copy title and URL" ), 2 );
 
-    QString datName = item->text( Row_DatName );
-    KURL datURL = m_board->url();
-    datURL.addPath( "/dat/" + datName );
-
-    Kita::Board::setName( Kita::datToBoard( datURL.url() ), m_board->name() );
-    Kita::Thread::setName( datURL.url(), item->text( Row_Subject ) );
-    Kita::Thread* thread = Kita::Thread::getByURL( datURL.url() );
-    KitaThreadInfo::setResNum( datURL.url(), item->text( Row_Read ).toInt() );
+    Kita::Thread* thread = Kita::Thread::getByURL( item->text( Row_DatURL ) );
 
     QClipboard* clipboard = QApplication::clipboard();
 
