@@ -12,6 +12,9 @@
 
 #include <config.h>
 
+#include <stdlib.h>
+#include <unistd.h>
+
 #include <kurl.h>
 #include <kdebug.h>
 #include <kprotocolmanager.h>
