@@ -8,32 +8,32 @@
 #include "libkita/board.h"
 
 //static const char * version = $VERSION$;
-static const char * version = "1.0";
+static const char* version = "1.0";
 
 typedef KParts::GenericFactory<KitaThreadPart> KitaThreadFactory;
- K_EXPORT_COMPONENT_FACTORY( libkitapart, KitaThreadFactory );
+K_EXPORT_COMPONENT_FACTORY( libkitapart, KitaThreadFactory );
 
-KAboutData * KitaThreadPart::createAboutData() // needed by GenericFactory
+KAboutData* KitaThreadPart::createAboutData()    // needed by GenericFactory
 {
-    KAboutData * about = new KAboutData( 
-            "kitapart",
-            I18N_NOOP("Kitapart plug-in"),
-            version,
-            "2ch thread dat viewer plugin.",
-            KAboutData::License_GPL,
-            "(C) 2003 Konqueror-plugin no hito, (C) 2003 Hideki Ikemoto",
-            "http://pc.2ch.net/linux/",
-            "no-mail"
-            );
+    KAboutData * about = new KAboutData(
+                             "kitapart",
+                             I18N_NOOP( "Kitapart plug-in" ),
+                             version,
+                             "2ch thread dat viewer plugin.",
+                             KAboutData::License_GPL,
+                             "(C) 2003 Konqueror-plugin no hito, (C) 2003 Hideki Ikemoto",
+                             "http://pc.2ch.net/linux/",
+                             "no-mail"
+                         );
     about->addAuthor( "Hideki Ikemoto", "Initial widget writer", "ikemo@wakaba.jp", 0 );
     about->addAuthor( "Konqueror-plugin no hito", "Kparts & some hacks.", 0, "http://pc.2ch.net/linux" );
     return about; // will be passed to GenericFactory.
 }
 
-KitaThreadPart::KitaThreadPart(  QWidget *parentWidget, const char *, QObject *parent, const char *name, const QStringList& )
-  : KParts::ReadOnlyPart( parent, name )
-  , m_threadview( 0 )
-  , m_extension( 0 )
+KitaThreadPart::KitaThreadPart( QWidget* parentWidget, const char*, QObject* parent, const char* name, const QStringList& )
+        : KParts::ReadOnlyPart( parent, name )
+        , m_threadview( 0 )
+        , m_extension( 0 )
 {
     m_threadview = new KitaThreadView( parentWidget ); // auto delete
     setInstance( KitaThreadFactory::instance() );
@@ -51,7 +51,7 @@ KitaThreadPart::~KitaThreadPart()
     }
 }
 
-KParts::BrowserExtension * KitaThreadPart::browserExtension() const
+KParts::BrowserExtension* KitaThreadPart::browserExtension() const
 {
     return m_extension;
 }
@@ -61,44 +61,43 @@ bool KitaThreadPart::openURL( const KURL& _url )
     kdDebug() << "KitaThreadPart::openURL _url: " << _url.url() << endl;
     m_url = _url;
     emit setWindowCaption( m_url.url() );
-    connect( m_threadview, SIGNAL( showThreadCompleted(const KURL&) ),
+    connect( m_threadview, SIGNAL( showThreadCompleted( const KURL& ) ),
              this, SLOT( slotOpenURLResult() ) );
 
-    m_threadview->showThread( Kita::Thread( m_url.url() ) );
+    m_threadview->showThread( Kita::Thread::getByURL( m_url.url() ) );
     emit started( 0 );
     return true;
 }
 
 bool KitaThreadPart::closeURL()
 {
-  m_threadview->killJob();
-  return true;
+    m_threadview->killJob();
+    return true;
 }
 
 void KitaThreadPart::slotOpenURLResult()
 {
-    disconnect( m_threadview, SIGNAL( showThreadCompleted(const KURL&) ),
-             this, SLOT( slotOpenURLResult() ) );
+    disconnect( m_threadview, SIGNAL( showThreadCompleted( const KURL& ) ),
+                this, SLOT( slotOpenURLResult() ) );
     emit setWindowCaption( m_threadview->threadName() );
     emit completed();
 }
 
-void KitaThreadPart::guiActivateEvent ( KParts::GUIActivateEvent *event )
+void KitaThreadPart::guiActivateEvent ( KParts::GUIActivateEvent* event )
 {
     //KParts::ReadOnlyPart::guiActivateEvent( event );
     if ( event->activated() )
         emit setWindowCaption( m_threadview->threadName() );
 }
 
-KitaThreadBrowserExtension::KitaThreadBrowserExtension( KitaThreadPart * parent )
-  : KParts::BrowserExtension( parent, "KitaThreadBrowserExtension" )
+KitaThreadBrowserExtension::KitaThreadBrowserExtension( KitaThreadPart* parent )
+        : KParts::BrowserExtension( parent, "KitaThreadBrowserExtension" )
 {
-    // DND Drop enable: 1st stage. 
+    // DND Drop enable: 1st stage.
     setURLDropHandlingEnabled( true ); // default: false
 }
 
 KitaThreadBrowserExtension::~KitaThreadBrowserExtension()
-{
-}
+{}
 
 // vim:sw=4:
