@@ -55,7 +55,7 @@ static const char* cookie_message =
     "Ǥ餦Ȥƽ񤭹ߤޤ\n";
 
 static const char* kokomade_yonda =
-    "<p style=\"background-color: #CCCCCC; text-align: center\">"
+    "<p id='kokomade_yonda' style=\"background-color: #CCCCCC; text-align: center\">"
     "ޤɤ"
     "</p>";
 
@@ -212,7 +212,7 @@ void KitaThreadView::update( const QString& result )
         if ( num == 1 ) {
             Kita::Thread::setName( m_thread->datURL(), comment.getSubject() );
         }
-        text += comment.toHtml( num );
+        text += comment.toHtml( num, KitaConfig::showMailAddress() );
 
         if ( prevResNum == num ) {
             QTextCodec * codec = QTextCodec::codecForName( "euc-jp" );
@@ -236,7 +236,7 @@ void KitaThreadView::update( const QString& result )
 
     m_threadPart->displayContents( text, m_thread->datURL() );
     // FIXME: ⤦äȤޤȤˡȤ
-    m_threadPart->gotoURL( m_thread, QMIN( prevResNum + 1, m_thread->resNum() ) );
+    m_threadPart->gotoURL( m_thread, QMIN( QMAX( prevResNum, 1 ), m_thread->resNum() ) );
     updateButton();
 
     emit showThreadCompleted( m_thread->url() );
@@ -265,7 +265,7 @@ const QString KitaThreadView::footer( int prevResNum ) const
     for ( target = 1; target < m_thread->resNum(); target += 100 ) {
         text += QString( " <a href=\"#%1\">%3</a> " ).arg( target ).arg( target );
     }
-    text += QString( " <a href=\"#%1\">New</a> " ).arg( prevResNum + 1 );
+    text += " <a href=\"#kokomade_yonda\">New</a> ";
     text += "<br/>";
 
     return text;
@@ -416,6 +416,10 @@ void KitaThreadView::slotOnURL( const QString& url )
         int refNum = 0;
         if ( url.at( 0 ) == '#' ) {
             refNum = url.mid( 1 ).toInt();
+        } else if ( url.left( 7 ) == "mailto:" ) {
+            DOM::Node node = m_threadPart->nodeUnderMouse().firstChild();
+            QString nodeValue = node.nodeValue().string();
+            refNum = nodeValue.toInt();
         } else {
             KURL filteredURL = filterReadCGI( KURL( m_thread->datURL(), url ) );
             refNum = filteredURL.ref().toInt();
