@@ -26,30 +26,10 @@
 #include <qcombobox.h>
 #include <qeucjpcodec.h>
 #include <qfile.h>
+#include <qmessagebox.h>
 
 #include <kio/job.h>
 
-const char* kaomoji[] = {
-    "",
-    "(ߢώ)!!!!!",
-    "ʎߧՎߡˎώ",
-    "(++)ώގ",
-    "((((((ߧ))))))ގގ̎ގَ̎ގ",
-    "(ء`)Ύގ",
-    "( _`)̎",
-    "(`)Ύ܎",
-    "ʎώˎ!!",
-    "(;`)ʎʎ",
-//  "(?)׎",
-    "(ߧ)ʎ?",
-    "ߎ(ɧ`)ߎ",
-    "(ߧՎ)Ύߎ",
-    "ʡϡˎ!!",
-    "(-`).()",
-    "(ҡϡ)Ҏގ",
-    NULL
-};
-
 KitaWriteDialogPrivate* KitaWriteDialog::s_private = 0;
 
 KitaWriteDialog::KitaWriteDialog( QWidget* parent, const char* name )
@@ -63,12 +43,11 @@ KitaWriteDialog::KitaWriteDialog( QWidget* parent, const char* name )
     mailLabel->setFont( font );
 
     faceCombo->clear();
-    int i = 0;
-    while ( kaomoji[ i ] ) {
-        QEucJpCodec codec;
-        QString str = codec.toUnicode( kaomoji[ i ], strlen( kaomoji[ i ] ) );
-        faceCombo->insertItem( str );
-        i++;
+    faceCombo->insertItem( "" );
+    QStringList list = KitaConfig::asciiArtList();
+    QStringList::iterator it;
+    for ( it = list.begin(); it != list.end(); ++it ) {
+        faceCombo->insertItem( *it );
     }
 }
 
@@ -220,4 +199,18 @@ void KitaWriteDialog::slotPostFinished( KIO::Job* job )
         delete this;
 }
 
+void KitaWriteDialog::reject()
+{
+    switch ( QMessageBox::warning( this, "Kita",
+                                   "If you close this dialog, you will lose text.\n"
+                                   "Do you want to close?", QMessageBox::Ok, QMessageBox::Cancel | QMessageBox::Default ) ) {
+    case QMessageBox::Ok:
+        KitaWriteDialogBase::reject();
+        break;
+    case QMessageBox::Cancel:
+        // do nothing
+        break;
+    }
+}
+
 // vim:sw=2:
