@@ -23,7 +23,7 @@ enum ThreadListViewRows {
     Row_Read,
     Row_Unread,
     Row_Board,
-    Row_DatName,
+    Row_Since,
     Row_DatURL
 };
 
